@@ -13,7 +13,7 @@ SYLO_HOME = f"{HOME_DIR}/.sylo"
 
 INPUT_OPTIONS = {
     "home": ["", "h", "q", "s", "t", "y", "i", "a"],
-    "task_menu": ["", "c", "m", "n", "d"],
+    "task_menu": ["", "c", "m", "n", "d", "l"],
 }
 
 
