@@ -36,7 +36,15 @@ class Display:
             return f"{self.theme}{string}{Style.RESET_ALL}"
 
     def print_poms(self, pom: int):
-        return f"{self.col(str(pom) + ' ' + self.add_plurality(self.pom_name), 'lmagenta')}"
+        return f"{self.col('(' + str(pom) + ' ' + self.add_plurality(self.pom_name) + ')', 'lmagenta')}"
+
+    def print_age(self, age: int):
+        if age > 7:
+            return f"{self.col('(' + str(age) + ' days old)', 'red')}"
+        elif 4 <= age <= 6:
+            return f"{self.col('(' + str(age) + ' days old)', 'red')}"
+        else:
+            return ""
 
     def print_timer(self, mode: str, timer_val: int, tasks: List = None):
         if mode == "work":
@@ -79,7 +87,7 @@ class Display:
 
     def print_insights(self):
         print(
-            f"\nTotal {self.col(self.add_plurality(self.pom_name), 'lmagenta')} today:          "
+            f"\nTotal {self.col(self.add_plurality(self.pom_name), 'lmagenta')} today:{self.fix_indent()}      "
             f"{self.col(str(int(self.durations.poms)), 'yellow')} "
             f"{self.add_plurality(self.pom_name)}"
             f"\nTotal {self.col('Work', 'red')} today:           "
@@ -138,17 +146,18 @@ class Display:
     def print_add_task_or_quit(self):
         print("\n")
         print(
-            f"{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
             f"{self.col('to go back')} "
-            f"\n{self.col('Press')} {self.col('N', 'yellow')} "
+            f"\n{self.col('N', 'yellow')} "
             f"{self.col('to add a new task')}"
-            f"\n{self.col('Press')} {self.col('C', 'yellow')} "
-            f"{self.col('to toggle completion of a task')}"
-            f"\n{self.col('Press')} {self.col('M', 'yellow')} "
-            f"{self.col('to move task to today')}"
-            f"\n{self.col('Press')} {self.col('D', 'yellow')} "
+            f"\n{self.col('C', 'yellow')} "
+            f"{self.col('to complete a task')}"
+            f"\n{self.col('M', 'yellow')} "
+            f"{self.col('to move a task to today')}"
+            f"\n{self.col('D', 'yellow')} "
             f"{self.col('to delete a task')}"
+            f"\n{self.col('L', 'yellow')} "
+            f"{self.col('to lump all incomplete tasks to today')}\n"
         )
 
     def print_new_task(self):
@@ -215,13 +224,13 @@ class Display:
             self.print_splash_prompt(mode)
 
     def print_tasks(self, tasks: List = None):
+        logger.info(tasks)
         complete_tasks = "\n".join(
             "".join(
                 map(
                     str,
-                    f"{self.col('--', 'lblue')} "
-                    f"{self.print_poms(t[3])}: "
-                    f"{self.trim_string(self.col(strike(t[2]),'green'),65)}",
+                    f"{self.col('->', 'lblue')} "
+                    f"{self.trim_string(strike(t[2]),65)}",
                 )
             )
             for t in tasks
@@ -231,8 +240,8 @@ class Display:
             "".join(
                 map(
                     str,
-                    f"{self.col('--', 'lblue')} "
-                    f"{self.print_poms(t[3])}: "
+                    f"{self.col('->', 'lblue')} "
+                    f"{self.print_poms(t[3])}{self.print_age(t[5])}: "
                     f"{tr.fill(self.col(t[2],'white'), 45)}",
                 )
             )
@@ -244,30 +253,14 @@ class Display:
         if incomplete_tasks:
             print(incomplete_tasks)
 
-    def print_incomplete_tasks(self, tasks: List = None):
-        incomplete_tasks = "\n".join(
-            "".join(
-                map(
-                    str,
-                    f"{self.col('--')} "
-                    f"{self.print_poms(t[3])}: "
-                    f"{tr.fill(t[2], 45)}",
-                )
-            )
-            for t in tasks
-            if t[4] == False
-        )
-        if incomplete_tasks:
-            print(incomplete_tasks)
-
     def print_tasks_with_id(self, tasks: List = None):
         complete_tasks = "\n".join(
             "".join(
                 map(
                     str,
-                    f"{self.col('--')} {self.col(t[0], 'yellow')}  "
+                    f"{self.col('->', 'lblue')} {self.col(t[0], 'yellow')}  "
                     f"{self.print_poms(t[3])}: "
-                    f"{self.trim_string(self.col(strike(t[2]),'green'),65)}",
+                    f"{self.trim_string(strike(t[2]),65)}",
                 )
             )
             for t in tasks
@@ -277,8 +270,8 @@ class Display:
             "".join(
                 map(
                     str,
-                    f"{self.col('--')} {self.col(t[0], 'yellow')}  "
-                    f"{self.print_poms(t[3])}: "
+                    f"{self.col('->', 'lblue')} {self.col(t[0], 'yellow')}  "
+                    f"{self.print_poms(t[3])}{self.print_age(t[5])}: "
                     f"{tr.fill(t[2], 45)}",
                 )
             )
