@@ -65,11 +65,12 @@ class Timer:
         self.tasks = database.select(
             f"SELECT"
             f'"id",'
-            f'"created_at",'
+            f'"assigned_date",'
             f'"description",'
             f'"effort",'
-            f'"complete"'
-            f"FROM tasks WHERE \"created_at\" = '{get_today()}' "
+            f'"complete",'
+            f"CAST(ROUND(JULIANDAY('now') - JULIANDAY(\"created_at\"),0) as integer) as age "
+            f"FROM tasks WHERE \"assigned_date\" = '{get_today()}' "
             f";"
         )
         self.display = display
@@ -217,7 +218,8 @@ class Insights:
             "when 3 then 'Wednesday'"
             "when 4 then 'Thursday'"
             "when 5 then 'Friday'"
-            "else 'Saturday' end as dayofweek,"
+            "when 6 then 'Saturday'"
+            "else 'No day' end as dayofweek,"
             "count(*) "
             "FROM tasks "
             "GROUP BY 1 "
@@ -225,11 +227,14 @@ class Insights:
             "LIMIT 1"
         )
         busiest_day_created = database.select(query.format("created_at"))
-        businest_day_completed = database.select(query.format("completed_at"))
+        busiest_day_completed = database.select(query.format("completed_at"))
         self.display.print_busy_days_header()
-        self.display.print_busy_days(
-            busiest_day_created[0][0], businest_day_completed[0][0]
-        )
+        try:
+            self.display.print_busy_days(
+                busiest_day_created[0][0], busiest_day_completed[0][0]
+            )
+        except IndexError:
+            print("\nTry using SYLO for a while for your working patterns to generate.")
 
 
 class Task:
@@ -243,12 +248,14 @@ class Task:
         database.execute(
             f"INSERT INTO tasks ("
             f'"created_at", '
+            f'"assigned_date", '
             f'"description", '
             f'"effort", '
             f'"complete", '
             f'"number_of_times_moved"'
             f") VALUES("
             f'"{self.date}",'
+            f'"{self.date}",'
             f'"{self.description}",'
             f'"{self.effort}",'
             f'"{self.complete}",'
@@ -306,11 +313,12 @@ class Sylo:
             self.tasks = database.select(
                 f"SELECT"
                 f'"id",'
-                f'"created_at",'
+                f'"assigned_date",'
                 f'"description",'
                 f'"effort",'
-                f'"complete"'
-                f"FROM tasks WHERE \"created_at\" = '{date}'"
+                f'"complete",'
+                f"CAST(ROUND(JULIANDAY('now') - JULIANDAY(\"created_at\"),0) as integer) as age "
+                f"FROM tasks WHERE \"assigned_date\" = '{date}'"
                 f";"
             )
             if with_id is False:
@@ -368,12 +376,27 @@ class Sylo:
             self.task_menu(dates)
         database.execute(
             f"UPDATE tasks SET "
-            f"\"created_at\" = '{get_today()}',"
+            f"\"assigned_date\" = '{get_today()}',"
             f'"number_of_times_moved" = "number_of_times_moved" + 1'
             f' WHERE "id" = {comp_input};'
         )
         self.task_menu(dates)
 
+    def task_menu_move_all(self, dates: List):
+        clear_screen()
+        self.display.print_header_small()
+        self.show_task(dates, True)
+        self.display.print_edit_task()
+        print(self.display.col("MOVED ANY OPEN TASKS TO TODAY", "red"))
+        sleep(1)
+        database.execute(
+            f"UPDATE tasks SET "
+            f"\"assigned_date\" = '{get_today()}',"
+            f'"number_of_times_moved" = "number_of_times_moved" + 1'
+            f' WHERE "complete" = False;'
+        )
+        self.task_menu(dates)
+
     def task_menu_delete(self, dates: List, task_ids: List[tuple]):
         clear_screen()
         self.display.print_header_small()
@@ -391,12 +414,8 @@ class Sylo:
         clear_screen()
         all_tasks = self.tasks = database.select(
             f"SELECT"
-            f'"id",'
-            f'"created_at",'
-            f'"description",'
-            f'"effort",'
-            f'"complete"'
-            f'FROM tasks WHERE "created_at" '
+            f'"id"'
+            f'FROM tasks WHERE "assigned_date" '
             f">= (SELECT DATETIME({(get_today())}, '-7 day'))"
             f";"
         )
@@ -417,6 +436,8 @@ class Sylo:
             self.task_menu_close(dates, all_task_ids)
         while usr_input.lower() == "m":
             self.task_menu_move(dates, all_task_ids)
+        while usr_input.lower() == "l":
+            self.task_menu_move_all(dates)
         while usr_input.lower() == "d":
             self.task_menu_delete(dates, all_task_ids)
 
@@ -597,12 +618,12 @@ def run(args, config):
         tasks=database.select(
             f"SELECT"
             f'"id",'
-            f'"created_at",'
+            f'"assigned_date",'
             f'"description",'
             f'"effort",'
-            f'"complete"'
-            f"FROM tasks "
-            f"WHERE \"created_at\" = '{get_today()}'"
+            f'"complete",'
+            f"CAST(ROUND(JULIANDAY('now') - JULIANDAY(\"created_at\"),0) as integer) as age "
+            f"FROM tasks WHERE \"assigned_date\" = '{get_today()}' "
             f";"
         ),
         config=config,
