@@ -90,7 +90,4 @@ def generate_date_range(end_date: str, number_of_days: int):
 
 
 def strike(text):
-    result = ""
-    for c in text:
-        result = result + c + "\u0336"
-    return result
+    return "".join(["\u0336{}".format(c) for c in text])
